# 8080 SDK

Use the SDK to quickly build code deployed on the 8080 platform.

- Access secrets stored on the 8080 platform
- Automatic tracing, available on the 8080 platform
- Get an OpenAI SDK compatible object with:
    - Completions API
    - Responses API
- Create and interact with sandboxes 